pilas.comportamientos.Proyectil

Package pilas :: Module comportamientos :: Class Proyectil |
[hide private]
[frames] | no frames]

# Class Proyectil

source code

        object --+
                 |
    Comportamiento --+
                     |
                    Proyectil

Hace que un actor se comporte como un proyectil.

Instance Methods | [hide private]
__init__(self, velocidad_maxima=5, aceleracion=1, angulo_de_movimiento=90, gravedad=0) Construye el comportamiento. | source code
iniciar(self, receptor) Se invoca cuando se anexa el comportamiento a un actor. | source code
actualizar(self) Actualiza el comportamiento en un instante dado. | source code
mover_respecto_angulo_movimiento(self) Mueve el actor hacia adelante respecto a su angulo de movimiento. | source code
Inherited from `Comportamiento`: `terminar` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, velocidad_maxima=5, aceleracion=1, angulo_de_movimiento=90, gravedad=0) (Constructor) | source code
Construye el comportamiento. :param velocidad_maxima: Velocidad máxima que alcanzará el proyectil. :param aceleracion: Valor entre 0 y 1 para indicar lo rápido que acelerará el actor. :param angulo_de_movimiento: Angulo en que se moverá el Actor. :param gravedad: La velocidad vertical con la que caerá el actor. Overrides: object.__init__

### iniciar(self, receptor) | source code
Se invoca cuando se anexa el comportamiento a un actor. :param receptor: El actor que comenzará a ejecutar este comportamiento. Overrides: Comportamiento.iniciar

### actualizar(self) | source code
Actualiza el comportamiento en un instante dado. Si este metodo retorna True entonces el actor dejará de ejecutar este comportamiento. Overrides: Comportamiento.actualizar (inherited documentation)